@@ -3,9 +3,11 @@
 # Simon Hausmann <hausmann@kde.org>
 from time import sleep
 import pcop
-import dcop
+import pydcop
 
-app = dcop.anyAppCalled( "kpresenter" )
+app = pydcop.anyAppCalled( "kpresenter" )
+
+if not app: raise RuntimeError, "Couldn't find a running KPresenter"
 
 doc = app.KoApplicationIface.getDocuments()[0]
 view = doc.view(0)
