@@ -41,7 +41,7 @@ function write_classlist( title, intro, classlist )
     text = '<h3>'+title+'</h3>';
     text += intro;
     text += '<ul>\n';
-    
+
     var hrefroot = '';
     for ( var i = 0; i < classlist.length; i++ )
     {
@@ -90,40 +90,46 @@ function document_statics( statics )
 {
     for ( var idx = 0; idx < statics.length; idx++ ) {
 	var name = statics[idx];
+	try
+	{
 	var obj = eval( name );
 	var fileText = write_page( name,
 		   'Bindings for the static ' + name + ' object.' + dump(obj) );
 	System.writeFile("jsref/" + name.toLowerCase() + ".html", fileText);
     }
+	catch(x)
+	{
+		println("Error: " + x );
+	}
+    }
 }
 
 //
-// Document the constructable objects
+// Build script that will document the constructable objects
 //
+
 function document_constructable( objects )
 {
     for ( var idx = 0; idx < objects.length; idx++ )
     {
-	    println('Class: ' + objects[idx] );
-	    if ( objects[idx] != 'TextStream' ) {
-	    
-		try {
-		    generate_docs_object( objects[idx], eval('new '+objects[idx]+'()') );
-		    println(', Success');
-		}
-		catch(x) {
-		    println(', Error ' + x );
-		    generate_docs_nocreate( objects[idx] );
-		    nocreate.push( objects[idx] );
-		}
-	    }
+	println('Document class: ' + objects[idx] );
+
+	try {
+	  generate_docs_object( objects[idx], Factory.createObject( objects[idx] ));
+		println(', Success');
+	}
+	catch(x) {
+		println(', Error ' + x );
+		generate_docs_nocreate( objects[idx] );
+		nocreate.push( objects[idx] );
+	}
     }
 }
-
 ////
 //// Main
 ////
 
+
 var statics = [ 'Factory', 'System', 'Global', 'StdDialog',
                 'StdAction', 'StdDirs', 'StdIcons', 'Qt' ];
 qttps = [];
@@ -141,7 +147,7 @@ cons = Factory.constructors().sort();
 cons += 'Part';
 
 for ( var i=0; i < tps.length; i++ ) {
-     
+
     if ( /^Q/.test(tps[i]) ) {
  	qttps.push( tps[i] );
     }
@@ -162,11 +168,10 @@ for ( var i=0; i < tps.length; i++ ) {
 // Generate object reference pages
 //
 
+document_constructable( tps );
 document_statics( statics );
 document_statics( expts );
 
-document_constructable( tps );
-
 generate_docs_object( 'TextStream', System.stdin );
 generate_docs_object( 'Application', application );
 generate_docs_object( 'KJSEmbedPart', part );
