@@ -953,13 +953,17 @@ dcop_disconnect_signal(VALUE self, VALUE sender, VALUE senderObj, VALUE signal,
 static VALUE
 dcop_process(VALUE /*self*/, VALUE target, VALUE slotname, VALUE args, VALUE data, VALUE replyTypeName, VALUE replyType, VALUE replyData)
 {
-	VALUE _data = rb_funcall(qt_internal_module, rb_intern("get_qbytearray"), 1, data);
-	QByteArray * dataArray = 0;
-	Data_Get_Struct(_data, QByteArray, dataArray);
+	smokeruby_object *o = value_obj_info(data);
+	if (o == 0 || o->ptr == 0) {
+		return Qfalse;
+	}
+	QByteArray * dataArray = (QByteArray*) o->ptr;
 	
-	VALUE _replyData = rb_funcall(qt_internal_module, rb_intern("get_qbytearray"), 1, replyData);
-	QByteArray * replyArray = 0;
-	Data_Get_Struct(_replyData, QByteArray, replyArray);
+	o = value_obj_info(replyData);
+	if (o == 0 || o->ptr == 0) {
+		return Qfalse;
+	}
+	QByteArray * replyArray = (QByteArray*) o->ptr;
 
 	InvokeDCOPSlot dcopSlot(target, rb_intern(StringValuePtr(slotname)), args, *dataArray, replyTypeName, replyType, *replyArray);
 	dcopSlot.next();
@@ -1060,114 +1064,8 @@ config_additem(int argc, VALUE * argv, VALUE self)
 	return self;
 }
 
-static VALUE
-choice_name(VALUE self)
-{
-	smokeruby_object *o = value_obj_info(self);
-	KConfigSkeleton::ItemEnum::Choice * choice = (KConfigSkeleton::ItemEnum::Choice *) o->ptr;
-	return rb_str_new2(choice->name.latin1());
-}
-
-static VALUE
-set_choice_name(VALUE self, VALUE name)
-{
-	smokeruby_object *o = value_obj_info(self);
-	KConfigSkeleton::ItemEnum::Choice * choice = (KConfigSkeleton::ItemEnum::Choice *) o->ptr;
-	choice->name = StringValuePtr(name);
-	return self;
-}
-
-static VALUE
-choice_label(VALUE self)
-{
-	smokeruby_object *o = value_obj_info(self);
-	KConfigSkeleton::ItemEnum::Choice * choice = (KConfigSkeleton::ItemEnum::Choice *) o->ptr;
-	return rb_str_new2(choice->label.latin1());
-}
-
-static VALUE
-set_choice_label(VALUE self, VALUE label)
-{
-	smokeruby_object *o = value_obj_info(self);
-	KConfigSkeleton::ItemEnum::Choice * choice = (KConfigSkeleton::ItemEnum::Choice *) o->ptr;
-	choice->label = StringValuePtr(label);
-	return self;
-}
-
-static VALUE
-choice_whatsthis(VALUE self)
-{
-	smokeruby_object *o = value_obj_info(self);
-	KConfigSkeleton::ItemEnum::Choice * choice = (KConfigSkeleton::ItemEnum::Choice *) o->ptr;
-	return rb_str_new2(choice->whatsThis.latin1());
-}
-
-static VALUE
-set_choice_whatsthis(VALUE self, VALUE whatsthis)
-{
-	smokeruby_object *o = value_obj_info(self);
-	KConfigSkeleton::ItemEnum::Choice * choice = (KConfigSkeleton::ItemEnum::Choice *) o->ptr;
-	choice->whatsThis = StringValuePtr(whatsthis);
-	return self;
-}
-
 #endif
 
-static VALUE
-udsatom_str(VALUE self)
-{
-	smokeruby_object *o = value_obj_info(self);
-	KIO::UDSAtom * udsatom = (KIO::UDSAtom *) o->ptr;
-	if (udsatom->m_str.isNull()) {
-		return Qnil;
-	} else {
-		return rb_str_new2(udsatom->m_str.latin1());
-	}
-}
-
-static VALUE
-udsatom_long(VALUE self)
-{
-	smokeruby_object *o = value_obj_info(self);
-	KIO::UDSAtom * udsatom = (KIO::UDSAtom *) o->ptr;
-	return LL2NUM(udsatom->m_long);
-}
-
-static VALUE
-udsatom_uds(VALUE self)
-{
-	smokeruby_object *o = value_obj_info(self);
-	KIO::UDSAtom * udsatom = (KIO::UDSAtom *) o->ptr;
-	return UINT2NUM(udsatom->m_uds);
-}
-
-static VALUE
-set_udsatom_str(VALUE self, VALUE str)
-{
-	smokeruby_object *o = value_obj_info(self);
-	KIO::UDSAtom * udsatom = (KIO::UDSAtom *) o->ptr;
-	udsatom->m_str = QString(StringValuePtr(str));
-	return self;
-}
-
-static VALUE
-set_udsatom_long(VALUE self, VALUE m_long)
-{
-	smokeruby_object *o = value_obj_info(self);
-	KIO::UDSAtom * udsatom = (KIO::UDSAtom *) o->ptr;
-	udsatom->m_long = NUM2LL(m_long);
-	return self;
-}
-
-static VALUE
-set_udsatom_uds(VALUE self, VALUE uds)
-{
-	smokeruby_object *o = value_obj_info(self);
-	KIO::UDSAtom * udsatom = (KIO::UDSAtom *) o->ptr;
-	udsatom->m_uds = NUM2UINT(uds);
-	return self;
-}
-
 void
 Init_korundum()
 {
@@ -1196,25 +1094,9 @@ Init_korundum()
 	rb_define_singleton_method(kde_module, "dcop_send", (VALUE (*) (...)) dcop_send, -1);
 	
 #if KDE_VERSION >= 0x030200
-
 	rb_define_method(kconfigskeleton_class, "addItem", (VALUE (*) (...)) config_additem, -1);
-	
-	rb_define_method(kconfigskeleton_itemenum_choice_class, "name", (VALUE (*) (...)) choice_name, 0);
-	rb_define_method(kconfigskeleton_itemenum_choice_class, "label", (VALUE (*) (...)) choice_label, 0);
-	rb_define_method(kconfigskeleton_itemenum_choice_class, "whatsThis", (VALUE (*) (...)) choice_whatsthis, 0);
-	rb_define_method(kconfigskeleton_itemenum_choice_class, "name=", (VALUE (*) (...)) set_choice_name, 1);
-	rb_define_method(kconfigskeleton_itemenum_choice_class, "label=", (VALUE (*) (...)) set_choice_label, 1);
-	rb_define_method(kconfigskeleton_itemenum_choice_class, "whatsThis=", (VALUE (*) (...)) set_choice_whatsthis, 1);
-
 #endif
 	
-	rb_define_method(kio_udsatom_class, "m_str", (VALUE (*) (...)) udsatom_str, 0);
-	rb_define_method(kio_udsatom_class, "m_long", (VALUE (*) (...)) udsatom_long, 0);
-	rb_define_method(kio_udsatom_class, "m_uds", (VALUE (*) (...)) udsatom_uds, 0);
-	rb_define_method(kio_udsatom_class, "m_str=", (VALUE (*) (...)) set_udsatom_str, 1);
-	rb_define_method(kio_udsatom_class, "m_long=", (VALUE (*) (...)) set_udsatom_long, 1);
-	rb_define_method(kio_udsatom_class, "m_uds=", (VALUE (*) (...)) set_udsatom_uds, 1);
-	
 	rb_require("KDE/korundum.rb");
 }
 
