@@ -1,4 +1,4 @@
-# Copyright (c) 2004
+# Copyright (c) 2005
 # 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
 # 
 # This file is part of PyQt.
@@ -15,7 +15,7 @@
 # 
 # You should have received a copy of the GNU General Public License along with
 # PyQt; see the file LICENSE.  If not, write to the Free Software Foundation,
-# Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #
 # This is the build script for PyQt.  It should be run in the top level
 # directory of the source distribution and by the Python interpreter for which
@@ -41,7 +41,7 @@ except:
     print "SIP v3.9 or later installed."
     sys.exit(1)
 
-config = sipconfig.SIPConfig("PyQt 3.12")
+config = sipconfig.SIPConfig("PyQt 3.14.1")
 
 
 # Initialise the globals.
