@@ -33,6 +33,7 @@
 #include <qcursor.h>
 #include <qobjectlist.h>
 #include <qsignalslotimp.h>
+#include <qcstring.h>
 
 #undef DEBUG
 #ifndef __USE_POSIX
@@ -67,6 +68,7 @@ extern Smoke *qt_Smoke;
 extern void init_qt_Smoke();
 extern void smokeruby_mark(void * ptr);
 extern void smokeruby_free(void * ptr);
+extern VALUE qchar_to_s(VALUE self);
 
 #ifdef DEBUG
 int do_debug = qtdb_gc;
@@ -916,8 +918,6 @@ get_VALUEtype(VALUE ruby_value)
 	r = "n";
     else if(TYPE(ruby_value) == T_STRING)
 	r = "s";
-    else if(strcmp(classname, "Qt::ByteArray") == 0)
-	r = "b";
     else if(ruby_value == Qtrue || ruby_value == Qfalse || strcmp(classname, "Qt::Boolean") == 0)
 	r = "B";
     else if(strcmp(classname, "Qt::Enum") == 0) {
@@ -1784,6 +1784,59 @@ class_name(VALUE self)
     return rb_funcall(klass, rb_intern("name"), 0);
 }
 
+// Allow classnames in both 'Qt::Widget' and 'QWidget' formats to be
+// used as an argument to Qt::Object.inherits()
+static VALUE
+inherits_qobject(int argc, VALUE * argv, VALUE /*self*/)
+{
+	if (argc != 1) {
+		return rb_call_super(argc, argv);
+	}
+
+	Smoke::Index * classId = classcache.find(StringValuePtr(argv[0]));
+
+	if (classId == 0) {
+		return rb_call_super(argc, argv);
+	} else {
+		VALUE super_class = rb_str_new2(qt_Smoke->classes[*classId].className);
+		return rb_call_super(argc, &super_class);
+	}
+}
+
+static VALUE
+qbytearray_data(VALUE self)
+{
+	smokeruby_object *o = value_obj_info(self);
+	if (o == 0 || o->ptr == 0) {
+		return Qnil;
+	}
+	QByteArray * dataArray = (QByteArray*) o->ptr;
+	return rb_str_new(dataArray->data(), (long) dataArray->size());
+}
+
+static VALUE
+qbytearray_size(VALUE self)
+{
+	smokeruby_object *o = value_obj_info(self);
+	if (o == 0 || o->ptr == 0) {
+		return Qnil;
+	}
+	QByteArray * dataArray = (QByteArray*) o->ptr;
+	return UINT2NUM(dataArray->size());
+}
+
+static VALUE
+qbytearray_setRawData(VALUE self, VALUE data)
+{
+	smokeruby_object *o = value_obj_info(self);
+	if (o == 0 || o->ptr == 0) {
+		return Qnil;
+	}
+	QByteArray * dataArray = (QByteArray*) o->ptr;
+	dataArray->setRawData(StringValuePtr(data), RSTRING(data)->len);
+	return self;
+}
+
 static void
 mocargs_free(void * ptr)
 {
@@ -1863,10 +1916,12 @@ isEnum(VALUE /*self*/, VALUE enumName_value)
 {
     char *enumName = StringValuePtr(enumName_value);
     Smoke::Index typeId = qt_Smoke->idType(enumName);
-    Smoke::Index classId = qt_Smoke->idClass(enumName);
-	// If something is a smoke type but not a class it must be an enum.
-	// Note this is true iff this function is called from qtruby.rb/checkarg()
-	return (typeId > 0 && classId == 0 ? Qtrue : Qfalse);
+	return	typeId > 0 
+			&& (	(qt_Smoke->types[typeId].flags & Smoke::tf_elem) == Smoke::t_enum
+					|| (qt_Smoke->types[typeId].flags & Smoke::tf_elem) == Smoke::t_ulong
+					|| (qt_Smoke->types[typeId].flags & Smoke::tf_elem) == Smoke::t_long
+					|| (qt_Smoke->types[typeId].flags & Smoke::tf_elem) == Smoke::t_uint
+					|| (qt_Smoke->types[typeId].flags & Smoke::tf_elem) == Smoke::t_int ) ? Qtrue : Qfalse;
 }
 
 static VALUE
@@ -2477,6 +2532,7 @@ create_qobject_class(VALUE /*self*/, VALUE package_value)
 	rb_define_method(klass, "pretty_print", (VALUE (*) (...)) pretty_print_qobject, 1);
 	rb_define_method(klass, "receivers", (VALUE (*) (...)) receivers_qobject, 0);
 	rb_define_method(klass, "className", (VALUE (*) (...)) class_name, 0);
+	rb_define_method(klass, "inherits", (VALUE (*) (...)) inherits_qobject, -1);
     
 	return klass;
 }
@@ -2498,9 +2554,15 @@ create_qt_class(VALUE /*self*/, VALUE package_value)
 		klass = kde_package_to_class(package);
 	}
 
-    if (strcmp(package, "Qt::MetaObject") == 0) {
-	qt_qmetaobject_class = klass;
-    }
+	if (strcmp(package, "Qt::MetaObject") == 0) {
+		qt_qmetaobject_class = klass;
+	} else if (strcmp(package, "Qt::ByteArray") == 0) {
+		rb_define_method(klass, "data", (VALUE (*) (...)) qbytearray_data, 0);
+		rb_define_method(klass, "size", (VALUE (*) (...)) qbytearray_size, 0);
+		rb_define_method(klass, "setRawData", (VALUE (*) (...)) qbytearray_setRawData, 1);
+	} else if (strcmp(package, "Qt::Char") == 0) {
+		rb_define_method(klass, "to_s", (VALUE (*) (...)) qchar_to_s, 0);
+	}
 
     return klass;
 }
@@ -2660,8 +2722,8 @@ Init_qtruby()
     rb_define_module_function(qt_internal_module, "cast_object_to", (VALUE (*) (...)) cast_object_to, 2);
     rb_define_module_function(qt_internal_module, "application_terminated=", (VALUE (*) (...)) set_application_terminated, 1);
     
-	rb_define_method(qt_module, "version", (VALUE (*) (...)) version, 0);
-    rb_define_method(qt_module, "qtruby_version", (VALUE (*) (...)) qtruby_version, 0);
+	rb_define_module_function(qt_module, "version", (VALUE (*) (...)) version, 0);
+    rb_define_module_function(qt_module, "qtruby_version", (VALUE (*) (...)) qtruby_version, 0);
 
 	rb_require("Qt/qtruby.rb");
 
