@@ -147,6 +147,17 @@ smokeruby_mark(void * p)
 			}
 			return;
 		}
+
+		if (isDerivedFromByName(o->smoke, className, "QCanvasItem")) {
+			QCanvasItem * item = (QCanvasItem *) o->smoke->cast(o->ptr, o->classId, o->smoke->idClass("QCanvasItem"));
+			QCanvas * canvas = item->canvas();
+			obj = getPointerObject(canvas);
+			if (obj != Qnil) {
+				if(do_debug & qtdb_gc) printf("Marking (%s*)%p -> %p\n", "QCanvas", canvas, (void*)obj);
+				rb_gc_mark(obj);
+			}
+			return;
+		}
 		
 		if (isDerivedFromByName(o->smoke, className, "QObject")) {
 			QObject * qobject = (QObject *) o->smoke->cast(o->ptr, o->classId, o->smoke->idClass("QObject"));
@@ -212,13 +223,13 @@ smokeruby_free(void * p)
 		}
 	} else if (strcmp(className, "QPopupMenu") == 0) {
 		QPopupMenu * item = (QPopupMenu *) o->ptr;
-		if (item->parentWidget(FALSE) != 0) {
+		if (item->parentWidget(false) != 0) {
 			free(o);
 			return;
 		}
 	} else if (isDerivedFromByName(o->smoke, className, "QWidget")) {
 		QWidget * qwidget = (QWidget *) o->smoke->cast(o->ptr, o->classId, o->smoke->idClass("QWidget"));
-		if (qwidget->parentWidget(TRUE) != 0) {
+		if (qwidget->parentWidget(true) != 0) {
 			free(o);
 			return;
 		}
@@ -863,7 +874,7 @@ static void marshall_QString(Marshall *m) {
 	     	} else {
                *(m->var()) = rstringFromQString(s);
 	     	}
-	     	if(m->cleanup())
+	     	if(m->cleanup() || m->type().isStack())
 	     	delete s;
          } else {
                 *(m->var()) = Qnil;
@@ -876,61 +887,22 @@ static void marshall_QString(Marshall *m) {
     }
 }
 
-static void marshall_QByteArray(Marshall *m) {
-    switch(m->action()) {
-      case Marshall::FromVALUE:
-	{
-	    VALUE rv = *(m->var());
-	    QByteArray *s = 0;
-		VALUE data = Qnil;
-	    if(rv != Qnil) {
-			if (rb_respond_to(rv, rb_intern("data")) != 0) {
-				// Qt::ByteArray - use the contents of the 'data' instance var
-				data = rb_funcall(qt_internal_module, rb_intern("get_qbytearray"), 1, rv);
-				if (TYPE(data) == T_DATA) {
-					// A C++ QByteArray inside the Qt::ByteArray
-					Data_Get_Struct(data, QByteArray, s);
-				} else {
-					// Or a ruby String inside
-            		s = new QByteArray(RSTRING(data)->len);
-					memcpy((void*)s->data(), StringValuePtr(data), RSTRING(data)->len);
-				}
-			} else {
-				// Ordinary ruby String - use the contents of the string
-            	s = new QByteArray(RSTRING(rv)->len);
-				memcpy((void*)s->data(), StringValuePtr(rv), RSTRING(rv)->len);
-			}
-        } else {
-            s = new QByteArray(0);
-	    }
-	    m->item().s_voidp = s;
-	    
-		m->next();
-	    
-		if(s && m->cleanup() && data == Qnil)
-		delete s;
+// The only way to convert a QChar to a QString is to
+// pass a QChar to a QString constructor. However,
+// QStrings aren't in the QtRuby api, so add this
+// convenience method 'Qt::Char.to_s' to get a ruby
+// string from a Qt::Char.
+VALUE
+qchar_to_s(VALUE self)
+{
+	smokeruby_object *o = value_obj_info(self);
+	if (o == 0 || o->ptr == 0) {
+		return Qnil;
 	}
-	break;
-      case Marshall::ToVALUE:
-	{
-		VALUE result;
-	    QByteArray *s = (QByteArray*)m->item().s_voidp;
-	    if(s) {
-			VALUE string = rb_str_new2("");
-			rb_str_cat(string, (const char *)s->data(), s->size());
-			result = rb_funcall(qt_internal_module, rb_intern("create_qbytearray"), 2, string, Data_Wrap_Struct(rb_cObject, 0, 0, s));
-        } else {
-			result = Qnil;
-		}
-		*(m->var()) = result;
-	    if(m->cleanup())
-		delete s;
-	}
-	break;
-      default:
-	m->unsupported();
-	break;
-    }
+
+	QChar * qchar = (QChar*) o->ptr;
+	QString s(*qchar);
+	return rstringFromQString(&s);
 }
 
 #if 0
@@ -1883,6 +1855,7 @@ TypeHandler Qt_handlers[] = {
     { "Q_UINT64&", marshall_ulonglong },
     { "Q_ULLONG", marshall_ulonglong },
     { "Q_ULLONG&", marshall_ulonglong },
+    { "signed int&", marshall_intR },
     { "int&", marshall_intR },
     { "int*", marshall_intR },
     { "bool&", marshall_boolR },
@@ -1895,8 +1868,6 @@ TypeHandler Qt_handlers[] = {
     { "QUObject*", marshall_QUObject },
     { "const QCOORD*", marshall_QCOORD_array },
     { "void", marshall_void },
-    { "QByteArray", marshall_QByteArray },
-    { "QByteArray&", marshall_QByteArray },
     { "QValueList<int>", marshall_QValueListInt },
     { "QValueList<int>&", marshall_QValueListInt },
     { "QValueList<QVariant>", marshall_QVariantList },
