@@ -83,21 +83,43 @@ module Qt
 		def |(a)
 			return Qt::|(self, a)
 		end
+
+#		Module has '<', '<=', '>' and '>=' operator instance methods, so pretend they
+#		don't exist by calling method_missing() explicitely
 		def <(a)
-			return Qt::<(self, a)
-		end
-		def <=(a)
-			return Qt::<=(self, a)
-		end
-		def >(a)
-			return Qt::>(self, a)
-		end
-		def >=(a)
-			return Qt::>=(self, a)
+			begin
+				Qt::method_missing(:<, self, a)
+			rescue
+				super(a)
+			end
 		end
 
-#		Object has an equality operator instance method, so pretend it
-#		doesn't exist by calling method_missing() explicitely
+		def <=(a)
+			begin
+				Qt::method_missing(:<=, self, a)
+			rescue
+				super(a)
+			end
+		end
+
+		def >(a)
+			begin
+				Qt::method_missing(:>, self, a)
+			rescue
+				super(a)
+			end
+		end
+
+		def >=(a)
+			begin
+				Qt::method_missing(:>=, self, a)
+			rescue
+				super(a)
+			end
+		end
+
+#		Object has a '==' operator instance method, so pretend it
+#		don't exist by calling method_missing() explicitely
 		def ==(a)
 			begin
 				Qt::method_missing(:==, self, a)
@@ -141,25 +163,6 @@ module Qt
 			return meths.uniq
 		end
 	end # Qt::Base
-			
-	require 'delegate.rb'
-	
-	# Allows a QByteArray to be wrapped in an instance which
-	# behaves just like a normal ruby String. TODO: override
-	# methods which alter the underlying string, in order to
-	# sync the QByteArray with the changed string.
-	# If the data arg is nil, the string is returned as the
-	# value instead. 
-	class ByteArray < DelegateClass(String)
-		attr_reader :private_data
-		attr_reader :data
-		
-		def initialize(string, data=nil)
-			super(string)
-			@private_data = data
-			@data = string
-		end
-	end
 	
 	# Delete the underlying C++ instance after exec returns
 	# Otherwise, rb_gc_call_finalizer_at_exit() can delete
@@ -172,6 +175,20 @@ module Qt
 		end
 	end
 	
+	class ByteArray < Qt::Base
+		def to_s
+			return data()
+		end
+		
+		def length
+			return size()
+		end
+
+		def data=(data)
+			setRawData(data)
+		end
+	end
+	
 	class Color < Qt::Base
 		def inspect
 			str = super
@@ -296,7 +313,7 @@ module Qt
 			pp.text str.sub(/>$/, "\n horData=%d,\n verData=%d>" % [horData, verData])
 		end
 	end
-	
+
 	class Date < Qt::Base
 		def inspect
 			str = super
@@ -333,6 +350,34 @@ module Qt
 		end
 	end
 	
+	class Variant < Qt::Base
+		def to_a
+			return toStringList()
+		end
+
+		def to_f
+			return toDouble()
+		end
+
+		def to_i
+			return toInt()
+		end
+
+		def to_int
+			return toInt()
+		end
+
+		def inspect
+			str = super
+			str.sub(/>$/, " typeName=%s>" % typeName)
+		end
+		
+		def pretty_print(pp)
+			str = to_s
+			pp.text str.sub(/>$/, " typeName=%s>" % typeName)
+		end
+	end
+	
 	# Provides a mutable numeric class for passing to methods with
 	# C++ 'int*' or 'int&' arg types
 	class Integer
@@ -374,6 +419,19 @@ module Qt
 			return Integer.new(@value >> n.to_i)
 		end
 		
+		def >(n) 
+			return @value > n.to_i
+		end
+		def >=(n) 
+			return @value >= n.to_i
+		end
+		def <(n) 
+			return @value < n.to_i
+		end
+		def <=(n) 
+			return @value <= n.to_i
+		end
+
 		def <=>(n)
 			if @value < n
 				return -1
@@ -434,6 +492,14 @@ module Qt
 		
 		def ==(n) return @value == n.to_i end
 		def to_i() return @value end
+		
+		def inspect
+			to_s
+		end
+
+		def pretty_print(pp)
+			pp.text "#<%s:0x%8.8x @type=%s, @value=%d>" % [self.class.name, object_id, type, value]
+		end
 	end
 	
 	# Provides a mutable boolean class for passing to methods with
@@ -485,9 +551,9 @@ module Qt
 		def Internal.checkarg(argtype, typename)
 			puts "      #{typename} (#{argtype})" if debug_level >= DebugLevel::High
 			if argtype == 'i'
-				if typename =~ /^int&?$|^signed$/
+				if typename =~ /^int&?$|^signed int&?$|^signed$|^Q_INT32&?$/
 					return 1
-				elsif typename =~ /^(?:short|ushort|uint|long|ulong|unsigned|float|double)$/
+				elsif typename =~ /^(?:short|ushort|unsigned short int|uint|long|ulong|unsigned long int|unsigned|float|double)$/
 					return 0
 				else 
 					t = typename.sub(/^const\s+/, '')
@@ -516,16 +582,8 @@ module Qt
 				if typename =~ /^(?:bool)[*&]?$/
 					return 0
 				end
-			elsif argtype == 'b'
-				# An argtype 'b' means a Qt::ByteArray has been passed to a C++ method expecting a QByteArray arg.
-				# In that case a Qt::ByteArray must take precedence over any String, and scores 3. Note that a
-				# ruby String would only score 2 when passed to the same QByteArray method - an alternative 
-				# method expecting a QString arg would take precedence over it with a score of 3.
-				if typename =~ /^(const )?(QByteArray[*&]?)$/
-					return 3
-				end
 			elsif argtype == 's'
-				if typename =~ /^(const )?((QByteArray|QChar)[*&]?)$/
+				if typename =~ /^(const )?((QChar)[*&]?)$/
 					return 1
 				elsif typename =~ /^(?:u?char\*|const u?char\*|(?:const )?(Q(C?)String)[*&]?)$/
 					qstring = !$1.nil?
@@ -548,7 +606,7 @@ module Qt
 				end
 			elsif argtype == 'u'
 				# Give nil matched against string types a higher score than anything else
-				if typename =~ /^(?:u?char\*|const u?char\*|(?:const )?((Q(C?)String)|QByteArray)[*&]?)$/
+				if typename =~ /^(?:u?char\*|const u?char\*|(?:const )?((Q(C?)String))[*&]?)$/
 					return 1
 				# Numerics will give a runtime conversion error, so they fail the match
 				elsif typename =~ /^(?:short|ushort|uint|long|ulong|signed|unsigned|int)$/
@@ -570,9 +628,7 @@ module Qt
 				elsif classIsa(argtype, t)
 					return 0
 				elsif isEnum(argtype) and 
-						(t =~ /int|uint|long|ulong|WFlags|WState|ProcessEventsFlags|ComparisonFlags/ or
-						t =~ /SFlags|SCFlags|WId|difference_type|ToolBarDock/ or
-						t =~ /KStyleFlags|KonqPopupFlags/)
+						(t =~ /int|Q_INT32|uint|Q_UINT32|long|ulong/ or isEnum(t))
 					return 0
 				end
 			end
@@ -588,20 +644,8 @@ module Qt
 		# Then use a throw to jump back to here with the C++ instance 
 		# wrapped in a new ruby variable of type T_DATA
 		def Internal.try_initialize(instance, *args)
-			# If a debugger calls an inspect method with the half 
-			# constructed instance, it will fail. So prevent that by
-			# defining a dummy 'do nothing' inspect method here
-			class <<instance
-				def inspect
-					return nil
-				end
-				def pretty_print(pp)
-					return nil
-				end
-			end
-			
 			initializer = instance.method(:initialize)
-			catch "newqt" do 
+			catch "newqt" do
 				initializer.call(*args)
 			end
 		end
@@ -745,25 +789,12 @@ module Qt
 					Qt::Internal::init_class(c)
 				end
 			end
-			# Special case QByteArray, as it's disguised as a ruby String
-			# and not in the public api.
-			@@classes['Qt::ByteArray'] = Qt::ByteArray
+
 			@@classes['Qt::Integer'] = Qt::Integer
 			@@classes['Qt::Boolean'] = Qt::Boolean
 			@@classes['Qt::Enum'] = Qt::Enum
 		end
 		
-		def Internal.create_qbytearray(string, data)
-			return Qt::ByteArray.new(string, data)
-		end
-		
-		def Internal.get_qbytearray(str)
-			if str.private_data.nil?
-				return str.data
-			end
-			return str.private_data
-		end
-		
 		def Internal.get_qinteger(num)
 			return num.value
 		end
@@ -1040,6 +1071,16 @@ module Kernel
 			method_missing(:exec, *k)
 		end
 	end
+
+	alias_method :_select, :select
+
+	def select(*k)
+		if k.length > 1 and k[0].kind_of? Array
+			_select(*k)
+		else
+			method_missing(:select, *k)
+		end
+	end
 end
 
 class Module
